@@ -194,3 +194,7 @@ def str2short_str(value: str, n: int = 5, chars=string.ascii_letters + string.di
         uuid_int //= len(chars)
 
     return short_str
+
+
+def eliminate_empty(data: list):
+    return [x for x in data if x is not None]
